MapController class abstract

Controller to programmatically interact with a FlutterMap.

Read the online documentation to get started.

Implementers

Constructors

MapController()
Controller to programmatically interact with a FlutterMap.
factory

Properties

camera MapCamera
Access the current MapCamera
no setter
hashCode int
The hash code for this object.
no setterinherited
mapEventStream Stream<MapEvent>
Stream of all emitted MapEvents
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Dispose of this controller.
fitCamera(CameraFit cameraFit) bool
Move and zoom the map to fit cameraFit.
move(LatLng center, double zoom, {Offset offset = Offset.zero, String? id}) bool
Moves and zooms the map to a center and zoom level
moveAndRotate(LatLng center, double zoom, double degree, {String? id}) → MoveAndRotateResult
Calls move and rotate together, but is more efficient for the combined operation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotate(double degree, {String? id}) bool
Rotates the map to a decimal degree around the current center, where 0° is North
rotateAroundPoint(double degree, {Offset? offset, String? id}) → MoveAndRotateResult
Rotates the map to a decimal degree around a custom screen point, where 0° is North
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

maybeOf(BuildContext context) MapController?
The controller for the closest FlutterMap ancestor. If this is called from a context with no FlutterMap ancestor a StateError will be thrown.
of(BuildContext context) MapController
The controller for the closest FlutterMap ancestor. If this is called from a context with no FlutterMap ancestor a StateError will be thrown.