onPointerMove property

PointerMoveCallback? onPointerMove
final

Called when a pointer is down and moves.

If used while dragging the map, this may emit the same point as by onPositionChanged, but might not due to map pixel snapping or a slight delay, or any other disconnect between the pointer and map camera.

Prefer using onPositionChanged, unless this is specifically required, such as obtaining the pointer position while the map camera is 'locked'.

Implementation

final PointerMoveCallback? onPointerMove;